@@ -1,8 +1,12 @@
+""" Select backend automaticaly. """
+
 from .base import SCMBackend
 
 
 class Backend(SCMBackend):
 
+    """ Check path and select backend automaticaly. """
+
     default_backends = 'git', 'mercurial', 'simple', 'null'
 
     def __init__(self, **kwargs):
@@ -10,6 +14,12 @@ class Backend(SCMBackend):
         self._backend = None
 
     def init_repo(self):
+        """ Check path.
+
+        :return object: A repo
+        :raise TypeError: Supported backend not found.
+
+        """
         from importlib import import_module
 
         backends = self.options.get('backends') or self.default_backends
@@ -26,12 +36,10 @@ class Backend(SCMBackend):
         if self._backend:
             self._repo = self._backend.repo
             self._revision = self._backend.revision
+            self._tag = self._backend.tag
             return self._repo
 
         raise TypeError('Invalid project: {0}'.format(self.path))
 
 
 auto = Backend()
-
-
-# pymode:lint_ignore=W0201
