@@ -1,5 +1,5 @@
-from django.conf.urls.defaults import patterns
 from django.http import HttpResponse
+from django.conf.urls import patterns
 
 
 urlpatterns = patterns(
